@@ -13,7 +13,7 @@ use Data::Object::ClassHas;
 
 extends 'Zing::Kernel';
 
-our $VERSION = '0.24'; # VERSION
+our $VERSION = '0.25'; # VERSION
 
 # ATTRIBUTES
 
@@ -142,7 +142,7 @@ L<Zing::Data>: Process Data
 
 =item *
 
-L<Zing::Domain>: Shared State Management
+L<Zing::Domain>: Shared State
 
 =item *
 
@@ -154,6 +154,10 @@ L<Zing::Lookup>: Domain Index
 
 =item *
 
+L<Zing::Table>: Generic Index
+
+=item *
+
 L<Zing::Mailbox>: Process Mailbox
 
 =item *
